delete_key

Function delete_key 

pub fn delete_key(
    lhs: &Value<'_>,
    rhs: &Value<'_>,
) -> Result<Value<'static>, EvalError>
v7.37.17 (17.6 siblings) — jsonb_delete(doc, key) — function form of the - operator. Removes an object key or an array element (by text match for objects, by index for arrays).