Subscriptions

Struct Subscriptions 

pub struct Subscriptions { /* private fields */ }

Implementations

Source

impl Subscriptions

pub fn new() -> Self

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn contains(&self, name: &str) -> bool

pub fn get(&self, name: &str) -> Option<&Subscription>

pub fn iter(&self) -> impl Iterator<Item = (&String, &Subscription)>

pub fn create( &mut self, name: String, sub: Subscription, ) -> Result<(), SubscriptionError>

pub fn drop(&mut self, name: &str) -> bool

pub fn update_last_received_pos(&mut self, name: &str, pos: u64) -> bool

v6.1.4 — update the worker’s last-applied master-WAL offset. Called by the subscription worker after each apply batch. Returns false when the subscription was dropped between when the worker fetched the record and when this call landed (so the worker can shut down cleanly).

pub fn serialize(&self) -> Vec<u8>

Format: [u16 num_subscriptions] for each: [u16 name_len][name bytes] [u32 conn_str_len][conn_str bytes] [u16 num_pubs] for each: [u16 p_len][p bytes] [u8 enabled] [u64 last_received_pos]

pub fn deserialize(buf: &[u8]) -> Result<Self, SubscriptionError>