pub fn parse_copy_from_file(sql: &str) -> Option<CopyFromFileSpec>Expand description
Parse sql and return its parts when it is a COPY … FROM '<file>'
statement — the host-side sniff for the file endpoint (any other
statement, or a parse error, returns None and the caller executes
normally).