pub fn parse_copy_to_file(sql: &str) -> Option<CopyToFileSpec>Expand description
Parse sql and return its parts when it is a COPY … TO '<file>'
statement (any other statement, or a parse error, returns None).
pub fn parse_copy_to_file(sql: &str) -> Option<CopyToFileSpec>Parse sql and return its parts when it is a COPY … TO '<file>'
statement (any other statement, or a parse error, returns None).